@@ -1,6 +1,9 @@
 package MooseX::Aliases::Meta::Trait::Method;
 BEGIN {
-  $MooseX::Aliases::Meta::Trait::Method::VERSION = '0.10';
+  $MooseX::Aliases::Meta::Trait::Method::AUTHORITY = 'cpan:DOY';
+}
+{
+  $MooseX::Aliases::Meta::Trait::Method::VERSION = '0.11';
 }
 use Moose::Role;
 # ABSTRACT: method metaclass trait for L<MooseX::Aliases>
@@ -17,6 +20,7 @@ no Moose::Role;
 1;
 
 __END__
+
 =pod
 
 =head1 NAME
@@ -25,7 +29,7 @@ MooseX::Aliases::Meta::Trait::Method - method metaclass trait for L<MooseX::Alia
 
 =head1 VERSION
 
-version 0.10
+version 0.11
 
 =head1 DESCRIPTION
 
@@ -37,23 +41,13 @@ This trait adds an attribute to metaclasses of aliased methods, to track which m
 
 Returns the name of the method that this method is an alias of.
 
-=head1 SEE ALSO
-
-=over 4
-
-=item *
-
-L<MooseX::Aliases>
-
-=back
-
 =head1 AUTHORS
 
 =over 4
 
 =item *
 
-Jesse Luehrs <doy at tozt dot net>
+Jesse Luehrs <doy@tozt.net>
 
 =item *
 
@@ -61,16 +55,15 @@ Chris Prather <chris@prather.org>
 
 =item *
 
-Justin Hunter <justin.d.hunter at gmail dot com>
+Justin Hunter <justin.d.hunter@gmail.com>
 
 =back
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011 by Jesse Luehrs.
+This software is copyright (c) 2013 by Jesse Luehrs.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
